==> com.liferay.layout.content.page.editor.web-1.0.20.jar: META-INF/resources/js/components/toolbar/segmentsExperiences/modal.es.js <==
"use strict";

Liferay.Loader.define("layout-content-page-editor-web@1.0.20/js/components/toolbar/segmentsExperiences/modal.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-web/liferay/compat/modal/Modal.es', './modal.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = exports.SegmentsExperienceSelectorModal = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireWildcard(require("frontend-js-metal-web$metal-soy"));

  require("frontend-js-web/liferay/compat/modal/Modal.es");

  var _modal = _interopRequireDefault(require("./modal.soy"));

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj.default = obj;return newObj;
    }
  }

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var SegmentsExperienceSelectorModal =
  /*#__PURE__*/
  function (_Component) {
    _inherits(SegmentsExperienceSelectorModal, _Component);

    function SegmentsExperienceSelectorModal() {
      _classCallCheck(this, SegmentsExperienceSelectorModal);

      return _possibleConstructorReturn(this, _getPrototypeOf(SegmentsExperienceSelectorModal).apply(this, arguments));
    }

    _createClass(SegmentsExperienceSelectorModal, [{
      key: "prepareStateForRender",

      /**
       * @inheritdoc
       * @memberof SegmentsExperienceSelectorModal
       * @param {object} state
       * @return {object}
       * @review
       */
      value: function prepareStateForRender(state) {
        if (!state.visible) {
          this.setState({
            _requiredNameError: false
          });
        }
      }
      /**
       * Acts as a middleware for the `onExperienceSubmit` form event
       * Checks experience name is present
       *
       * @memberof SegmentsExperienceSelectorModal
       * @review
       */

    }, {
      key: "_handleFormSubmit",
      value: function _handleFormSubmit(event) {
        event.preventDefault();
        var nameInput = this.refs.experienceModal.refs.experienceName;
        var segmentIdInput = this.refs.experienceModal.refs.experienceSegmentId;
        var validName = nameInput.value && nameInput.value.replace(/ /g, '');

        if (this.experienceForm && this.experienceForm.onExperienceSubmit && validName) {
          this.experienceForm.onExperienceSubmit(nameInput.value, segmentIdInput.value);
        } else if (!validName) {
          this.setState({
            _requiredNameError: true
          });
          nameInput.focus();
        }
      }
    }]);

    return SegmentsExperienceSelectorModal;
  }(_metalComponent.default);
  /**
   * State definition
   * @review
   * @static
   * @type {!object}
   */

  exports.SegmentsExperienceSelectorModal = SegmentsExperienceSelectorModal;
  SegmentsExperienceSelectorModal.STATE = {
    /**
     * Controls the visibility of the required name error
     * @default false
     * @memberOf SegmentsExperienceSelectorModal
     * @review
     * @type {boolean}
     */
    _requiredNameError: _metalSoy.Config.bool().internal().value(false)
  };

  _metalSoy.default.register(SegmentsExperienceSelectorModal, _modal.default);

  var _default = SegmentsExperienceSelectorModal;
  exports.default = _default;
  //# sourceMappingURL=modal.es.js.map
});
//# sourceMappingURL=modal.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/toolbar/segmentsExperiences/modal.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/toolbar/segmentsExperiences/modal.es", ['module', 'exports', 'require', 'frontend-js-web/liferay/compat/modal/Modal.es', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', './modal.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.SegmentsExperienceSelectorModal = void 0;

  require("frontend-js-web/liferay/compat/modal/Modal.es");

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireWildcard(require("frontend-js-metal-web$metal-soy"));

  var _modal = _interopRequireDefault(require("./modal.soy"));

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj["default"] = obj;return newObj;
    }
  }

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var SegmentsExperienceSelectorModal =
  /*#__PURE__*/
  function (_Component) {
    _inherits(SegmentsExperienceSelectorModal, _Component);

    function SegmentsExperienceSelectorModal() {
      _classCallCheck(this, SegmentsExperienceSelectorModal);

      return _possibleConstructorReturn(this, _getPrototypeOf(SegmentsExperienceSelectorModal).apply(this, arguments));
    }

    _createClass(SegmentsExperienceSelectorModal, [{
      key: "prepareStateForRender",

      /**
       * @inheritdoc
       * @memberof SegmentsExperienceSelectorModal
       * @param {object} state
       * @return {object}
       * @review
       */
      value: function prepareStateForRender(state) {
        if (!state.visible) {
          this.setState({
            _requiredNameError: false
          });
        }
      }
      /**
       * Acts as a middleware for the `onExperienceSubmit` form event
       * Checks experience name is present
       *
       * @memberof SegmentsExperienceSelectorModal
       * @review
       */

    }, {
      key: "_handleFormSubmit",
      value: function _handleFormSubmit(event) {
        event.preventDefault();
        var nameInput = this.refs.experienceModal.refs.experienceName;
        var segmentIdInput = this.refs.experienceModal.refs.experienceSegmentId;
        var validName = nameInput.value && nameInput.value.replace(/ /g, '');

        if (this.experienceForm && this.experienceForm.onExperienceSubmit && validName) {
          this.experienceForm.onExperienceSubmit(nameInput.value, segmentIdInput.value);
        } else if (!validName) {
          this.setState({
            _requiredNameError: true
          });
          nameInput.focus();
        }
      }
      /**
       * @param {MouseEvent} event
       * @memberof SegmentsExperienceSelectorModal
       */

    }, {
      key: "_handleNewSegmentClick",
      value: function _handleNewSegmentClick(event) {
        event.preventDefault();
        var nameInput = this.refs.experienceModal.refs.experienceName;

        if (nameInput) {
          var name = nameInput.value;
          this.onNewSegmentClick(this.type, name);
        }
      }
    }]);

    return SegmentsExperienceSelectorModal;
  }(_metalComponent["default"]);
  /**
   * State definition
   * @review
   * @static
   * @type {!object}
   */

  exports.SegmentsExperienceSelectorModal = SegmentsExperienceSelectorModal;
  SegmentsExperienceSelectorModal.STATE = {
    /**
     * Controls the visibility of the required name error
     * @default false
     * @memberOf SegmentsExperienceSelectorModal
     * @review
     * @type {boolean}
     */
    _requiredNameError: _metalSoy.Config.bool().internal().value(false),

    /**
     * Function to execute when clicking New Segment button
     *
     * @memberOf SegmentsExperienceSelectorModal
     * @review
     * @type {function}
     */
    onNewSegmentClick: _metalSoy.Config.func().required(),

    /**
     * The type of experience modal, so it can inform when
     * executing prop functions
     *
     * @memberOf SegmentsExperienceSelectorModal
     * @review
     * @type {'edition'|'creation'}
     */
    type: _metalSoy.Config.string().required()
  };

  _metalSoy["default"].register(SegmentsExperienceSelectorModal, _modal["default"]);

  var _default = SegmentsExperienceSelectorModal;
  exports["default"] = _default;
  //# sourceMappingURL=modal.es.js.map
});
//# sourceMappingURL=modal.es.js.map
